from .._request_handler import RequestHandler
from .store import Store


class DataStore:
    """Data Store client for browsing files and folders in store connectors."""

    def __init__(self, request_handler: RequestHandler):
        """
        Initialize the DataStore client.

        Args:
            request_handler: The request handler for making API calls
        """
        self.store = Store(request_handler)
