from .._request_handler import AsyncRequestHandler
from .store import AsyncStore


class AsyncDataStore:
    """Async Data Store client for browsing files and folders in store connectors."""

    def __init__(self, request_handler: AsyncRequestHandler):
        """
        Initialize the AsyncDataStore client.

        Args:
            request_handler: The async request handler for making API calls
        """
        self.store = AsyncStore(request_handler)
